"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const operators_1 = require("rxjs/operators");
const example_store_1 = require("../lib/utils/example-store");
describe('Store', () => {
    beforeAll(() => {
        process.env = Object.assign(process.env, { isTesting: 'true' });
    });
    it('Creates a Store', (done) => __awaiter(this, void 0, void 0, function* () {
        example_store_1.state$.pipe(operators_1.take(1)).subscribe(data => {
            expect(data).toEqual({
                total: 0,
                changed: false
            });
            done();
        });
    }));
    it('Update State', (done) => __awaiter(this, void 0, void 0, function* () {
        example_store_1.state$.pipe(operators_1.skip(1), operators_1.take(1)).subscribe(data => {
            expect(data).toEqual({
                total: 10,
                changed: true
            });
            done();
        });
        example_store_1.setTotal10ChangedTrue();
    }));
    it('Update State Partially', (done) => __awaiter(this, void 0, void 0, function* () {
        example_store_1.state$.pipe(operators_1.skip(1), operators_1.take(1)).subscribe(data => {
            expect(data).toEqual({
                total: 20,
                changed: true
            });
            done();
        });
        example_store_1.setTotal20();
    }));
    it('Retrieve current State', () => {
        const currentState = example_store_1.getCurrentState();
        expect(currentState).toEqual({
            total: 20,
            changed: true
        });
    });
    it('Update State using Callback', (done) => __awaiter(this, void 0, void 0, function* () {
        example_store_1.state$.pipe(operators_1.skip(1), operators_1.take(1)).subscribe(data => {
            expect(data).toEqual({
                total: 40,
                changed: true
            });
            done();
        });
        example_store_1.setTotalDouble();
    }));
});
