"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const clone_1 = require("./utils/clone");
function createStore(initialState) {
    const behavior$ = new rxjs_1.BehaviorSubject(clone_1.clone(initialState));
    const updateState = (request) => {
        const isFunction = request instanceof Function;
        const currentState = clone_1.clone(behavior$.getValue());
        const newKeys = isFunction ? request(currentState) : request;
        behavior$.next(Object.assign({}, currentState, newKeys));
    };
    function stateInjector(func) {
        return () => func(behavior$.getValue());
    }
    const getCurrentState = () => behavior$.getValue();
    const state$ = behavior$.asObservable();
    return {
        state$,
        stateInjector,
        updateState,
        getCurrentState,
    };
}
exports.createStore = createStore;
